package com.doc.biz.controller;

import com.doc.biz.service.IMongoService;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文件上传
 *
 * @author wukai
 * @date 2023-08-15
 */
@Slf4j
@RestController
@RequestMapping("/api")
public class FileUploadController extends BaseController {

    /**
     * 文件上传实现类
     */
    @Resource
    private IMongoService mongoService;
    @Resource
    private StringRedisTemplate stringRedisTemplate;


    /**
     * 文件上传
     *
     * @param file
     * @return
     */
    @PostMapping("/upload")
    public AjaxResult uploadFile(@RequestParam(value = "file") MultipartFile file) {
        try {
            return success(mongoService.uploadFile(file));
        } catch (Exception e) {
            log.error("文件上传失败：", e);
            return error(e.getMessage());
        }
    }

    /**
     * 多文件上传
     *
     * @param files
     * @return
     */
    @PostMapping("/uploadFiles")
    public AjaxResult uploadFile(@RequestParam(value = "files") List<MultipartFile> files) {
        try {
            return success(mongoService.uploadFiles(files));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }


    /**
     * 文件删除
     *
     * @param fileId
     * @return
     */
    @DeleteMapping("/remove/{fileId}")
    public AjaxResult removeFile(@PathVariable(name = "fileId") String fileId) {
        mongoService.removeFile(fileId);
        return success("删除成功");
    }

}
